@@ -22,10 +22,10 @@ def to_prefecture(postcode: str):
     cleaned_postcode = postcode.replace('-', '')
     filtered = filter(lambda x: x[0] == cleaned_postcode, postcodes)
     prefectures_counter = Counter([x[1] for x in filtered])
-    most_common = prefectures_counter.most_common(1)
-    if most_common:
+    try:
+        most_common = prefectures_counter.most_common(1)
         return most_common[0][0]
-    else:
+    except IndexError:
         return None
 
 
@@ -40,8 +40,8 @@ def to_city(postcode: str):
     cleaned_postcode = postcode.replace('-', '')
     filtered = filter(lambda x: x[0] == cleaned_postcode, postcodes)
     cities_counter = Counter([x[2] for x in filtered])
-    most_common = cities_counter.most_common(1)
-    if most_common:
+    try:
+        most_common = cities_counter.most_common(1)
         return most_common[0][0].replace('　', '')
-    else:
+    except IndexError:
         return None
